@@ -404,6 +404,9 @@ INVALIDPARAMETERVALUE_EXTERNALIPQUOTALIMITED = 'InvalidParameterValue.ExternalIp
 # 非GPU实例不允许转为GPU实例。
 INVALIDPARAMETERVALUE_GPUINSTANCEFAMILY = 'InvalidParameterValue.GPUInstanceFamily'
 
+# 非CDC场景不支持HpcClusterBusinessId。
+INVALIDPARAMETERVALUE_HPCCLUSTERBUSINESSIDNOTSUPPORTED = 'InvalidParameterValue.HpcClusterBusinessIdNotSupported'
+
 # 您的高性能计算集群已经绑定其他可用区，不能购买当前可用区机器。
 INVALIDPARAMETERVALUE_HPCCLUSTERIDZONEIDNOTMATCH = 'InvalidParameterValue.HpcClusterIdZoneIdNotMatch'
 
@@ -1157,6 +1160,9 @@ UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 # 共享镜像不支持导出。
 UNSUPPORTEDOPERATION_SHAREDIMAGEEXPORTUNSUPPORTED = 'UnsupportedOperation.SharedImageExportUnsupported'
 
+# 从其他账号共享的镜像不支持修改属性。
+UNSUPPORTEDOPERATION_SHAREDIMAGEMODIFYUNSUPPORTED = 'UnsupportedOperation.SharedImageModifyUnsupported'
+
 # 请求不支持特殊机型的实例
 UNSUPPORTEDOPERATION_SPECIALINSTANCETYPE = 'UnsupportedOperation.SpecialInstanceType'
 
